@@ -1,6 +1,7 @@
 from django.utils import translation
 from django.core.exceptions import ObjectDoesNotExist
 from django.conf import settings
+from django.contrib.auth.models import SiteProfileNotAvailable
 
 from userena import settings as userena_settings
 
@@ -18,7 +19,7 @@ class UserenaLocaleMiddleware(object):
             if request.user.is_authenticated():
                 try:
                     profile = request.user.get_profile()
-                except ObjectDoesNotExist:
+                except (ObjectDoesNotExist, SiteProfileNotAvailable):
                     profile = False
 
                 if profile:
