@@ -1,18 +1,20 @@
 from django.test import TestCase
 from django.core.management import call_command
-from django.contrib.auth.models import User, Permission
+from django.contrib.auth.models import Permission
 from django.contrib.contenttypes.models import ContentType
 
 from userena.models import UserenaSignup
 from userena.managers import ASSIGNED_PERMISSIONS
 from userena import settings as userena_settings
-from userena.utils import get_profile_model
+from userena.utils import get_profile_model, get_user_model
 
 from guardian.shortcuts import remove_perm
 from guardian.models import UserObjectPermission
 
 import datetime
 
+User = get_user_model()
+
 class CleanExpiredTests(TestCase):
     user_info = {'username': 'alice',
                  'password': 'swordfish',
@@ -111,10 +113,10 @@ class CheckPermissionTests(TestCase):
         # TODO: Dirty! Currently we check for the warning by getting a 100%
         # test coverage, meaning that it dit output some warning.
         user = UserenaSignup.objects.create_user(**self.user_info)
-        
+
         # remove the profile of this user
         get_profile_model().objects.get(user=user).delete()
-        
+
         # run the command to check for the warning.
         call_command('check_permissions', test=True)
-     
+
